==> moonlight-1.20-2.16.15-fabric-sources.jar: net/mehvahdjukaar/moonlight/api/client/model/CustomModelLoader.java <==
package net.mehvahdjukaar.moonlight.api.client.model;

import com.google.gson.JsonDeserializationContext;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParseException;
import net.mehvahdjukaar.moonlight.api.platform.ClientHelper;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_1088;
import net.minecraft.class_2960;
import net.minecraft.class_3665;
import net.minecraft.class_4730;
import net.minecraft.class_7775;
import net.minecraft.class_793;
import net.minecraft.client.resources.model.*;
import java.util.function.Function;

public interface CustomModelLoader {

    CustomGeometry deserialize(JsonObject json, JsonDeserializationContext context) throws JsonParseException;


    // helper function you'll likely only need here
    static class_1087 parseModel(JsonElement j, class_7775 modelBaker, Function<class_4730, class_1058> spriteGetter, class_3665 transform, class_2960 location) {
        class_793 model;
        if (j.isJsonPrimitive()) {
            model = (class_793) modelBaker.method_45872(class_2960.method_12829(j.getAsString()));
        } else {
            model = ClientHelper.parseBlockModel(j);
        }
        model.method_45785(modelBaker::method_45872);
        if (model == modelBaker.method_45872(class_1088.field_5374)) {
            throw new JsonParseException("Found missing model while parsing nested model " + location);
        }
        return model.method_3446(modelBaker, model, spriteGetter, transform, location, true);
    }
}

==> moonlight-1.21-2.24.1-fabric-sources.jar: net/mehvahdjukaar/moonlight/api/client/model/CustomModelLoader.java <==
package net.mehvahdjukaar.moonlight.api.client.model;

import com.google.gson.JsonDeserializationContext;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParseException;
import net.mehvahdjukaar.moonlight.api.platform.ClientHelper;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_1088;
import net.minecraft.class_2960;
import net.minecraft.class_3665;
import net.minecraft.class_4730;
import net.minecraft.class_7775;
import net.minecraft.class_793;
import net.minecraft.client.resources.model.*;
import java.util.function.Function;

public interface CustomModelLoader {

    CustomGeometry deserialize(JsonObject json, JsonDeserializationContext context) throws JsonParseException;


    // helper function you'll likely only need here
    static class_1087 parseModel(JsonElement j, class_7775 modelBaker, Function<class_4730, class_1058> spriteGetter, class_3665 transform) {
        class_793 model;
        if (j.isJsonPrimitive()) {
            model = (class_793) modelBaker.method_45872(class_2960.method_60654(j.getAsString()));
        } else {
            model = ClientHelper.parseBlockModel(j);
        }
        model.method_45785(modelBaker::method_45872);
        if (model == modelBaker.method_45872(class_1088.field_5374)) {
            throw new JsonParseException("Found missing model while parsing nested model " + j);
        }

        return model.method_4753(modelBaker, spriteGetter, transform);
    }
}
